#ifndef NT2_INCLUDE_FUNCTIONS_IF_ELSE_ZERO_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_IF_ELSE_ZERO_HPP_INCLUDED

#include <nt2/boolean/include/functions/if_else_zero.hpp>

#endif
